import os
import streamlit as st
import streamlit.components.v1 as components
from st_screen_stats import IS_RELEASE

__RELEASE = False

# if not IS_RELEASE:

if not __RELEASE:
    _st_screen_ranges = components.declare_component(

        "st_screen_ranges",

        url="http://localhost:3001",
    )
else:
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _st_screen_ranges = components.declare_component("st_screen_ranges", path=build_dir)


class WindowScreenRange:
    """
    Built to help get updates you care about with regards to the window screen size. 
    Data is only sent if the desired window size chosen is met.
    """

    def __init__(self) -> None:
        pass

    def WidthUpperLimit(self, upperRange:int=None, key=None, default=None):
        """
        Send boolean if window width is lower than or equal to selected upper range window width
        Args:
            - upperRange: integer upper range
        """

        if upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowSingleLimit", rangeType="upper", heightWidth="width", upperRange=upperRange, key=key, default=default)

        return value
    
    def WidthLowerLimit(self, lowerRange:int=None, key=None, default=None):
        """
        Send boolean if window width is higher than or equal to selected lower range window width
        Args:
            - lowerRange: integer lower range
        """

        if lowerRange == None or type(lowerRange) != int:
            return

        value = _st_screen_ranges(windowType="windowSingleLimit", rangeType="lower", heightWidth="width", lowerRange=lowerRange, key=key, default=default)

        return value
    
    def HeightUpperLimit(self, upperRange:int=None, key=None, default=None):
        """
        Send boolean if window height is lower than or equal to selected upper range window height
        Args:
            - upperRange: integer upper range
        """

        if upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowSingleLimit", rangeType="upper", heightWidth="height", upperRange=upperRange, key=key, default=default)

        return value
    
    def HeightLowerLimit(self, lowerRange:int=None, key=None, default=None):
        """
        Send boolean if window height is higher than or equal to selected lower window height
        Args:
            - lowerRange: integer lower range
        """

        if lowerRange == None or type(lowerRange) != int:
            return

        value = _st_screen_ranges(windowType="windowSingleLimit", rangeType="lower", heightWidth="height", lowerRange=lowerRange, key=key, default=default)

        return value
    
    def WidthUpperLimitTop(self, upperRange:int=None, key=None, default=None):
        """
        Send boolean if window top (the upper most browser window) width is lower than or equal to selected upper window width
        Args:
            - upperRange: integer upper range
        """

        if upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowTopSingleLimit", rangeType="upper", heightWidth="width", upperRange=upperRange, key=key, default=default)

        return value
    
    def WidthLowerLimitTop(self, lowerRange:int=None, key=None, default=None):
        """
        Send boolean if window top (the upper most browser window) width is higher than or equal to desired lower window width
        Args:
            - lowerRange: integer lower range
        """

        if lowerRange == None or type(lowerRange) != int:
            return

        value = _st_screen_ranges(windowType="windowTopSingleLimit", rangeType="lower", heightWidth="width", lowerRange=lowerRange, key=key, default=default)

        return value
    
    def HeightUpperLimitTop(self, upperRange:int=None, key=None, default=None):
        """
        Send boolean if window top (the upper most browser window) height is lower than or equal to desired upper window height
        Args:
            - upperRange: integer upper range
        """

        if upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowTopSingleLimit", rangeType="upper", heightWidth="height", upperRange=upperRange, key=key, default=default)

        return value
    
    def HeightLowerLimitTop(self, lowerRange:int=None, key=None, default=None):
        """
        Send boolean if window top (the upper most browser window) height is higher than or equal to desired lower window height
        Args:
            - lowerRange: integer lower range
        """

        if lowerRange == None or type(lowerRange) != int:
            return

        value = _st_screen_ranges(windowType="windowTopSingleLimit", rangeType="lower", heightWidth="height", lowerRange=lowerRange, key=key, default=default)

        return value
    
    def WidthRange(self, lowerRange:int=None, upperRange:int=None, key=None, default=None):
        """
        Send boolean if window width is between the desired lower and upper range
        Args:
            - lowerRange: integer lower range
            - upperRange: integer upper range
        """

        if lowerRange == None or type(lowerRange) != int or upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowUpperLowerJoint", heightWidth="width", lowerRange=lowerRange, upperRange=upperRange, key=key, default=default)

        return value
    
    def HeightRange(self, lowerRange:int=None, upperRange:int=None, key=None, default=None):
        """
        Send boolean if window height is between the desired lower and upper range
        Args:
            - lowerRange: integer lower range
            - upperRange: integer upper range
        """

        if lowerRange == None or type(lowerRange) != int or upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowUpperLowerJoint", heightWidth="height", lowerRange=lowerRange, upperRange=upperRange, key=key, default=default)

        return value
    
    def WidthTopRange(self, lowerRange:int=None, upperRange:int=None, key=None, default=None):
        """
        Send boolean if top window (browser) width is between the desired lower and upper range
        Args:
            - lowerRange: integer lower range
            - upperRange: integer upper range
        """

        if lowerRange == None or type(lowerRange) != int or upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowTopUpperLowerJoint", heightWidth="width", lowerRange=lowerRange, upperRange=upperRange, key=key, default=default)

        return value
    
    def HeightTopRange(self, lowerRange:int=None, upperRange:int=None, key=None, default=None):
        """
        Send boolean if top window (browser) height is between the desired lower and upper range
        Args:
            - lowerRange: integer lower range
            - upperRange: integer upper range
        """

        if lowerRange == None or type(lowerRange) != int or upperRange == None or type(upperRange) != int:
            return

        value = _st_screen_ranges(windowType="windowTopUpperLowerJoint", heightWidth="height", lowerRange=lowerRange, upperRange=upperRange, key=key, default=default)

        return value
    
    




import os
import time
import streamlit as st
from typing import Literal, Optional, Union
import streamlit.components.v1 as components
from st_screen_stats import IS_RELEASE

if not IS_RELEASE:
    _st_screen_data = components.declare_component(

        "st_screen_data",

        url="http://localhost:3001",
    )
else:
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _st_screen_data = components.declare_component("st_screen_data", path=build_dir)


class ScreenData:
    """
    Component that uses react to derive various window screen stats.
    Two methods:
        1. st_screen_data_window() - get screen stats based on size of window/iframe
        2. st_screen_data_window_top() - get screen stats based on upper most window -> recommended
    
        Args:
            - setTimeout: this dictates period pause until data is received after resize. Default is 1000 (1 second)
    """

    def __init__(self, setTimeout:Union[int,float]=1000, useNativePause:bool=True) -> None:
        """
            - setTimeout: amount of time for component to wait before sending traffic/data in ms default is 1000ms (1 sec).
        """
        self.setTimeout = setTimeout
        self.useNativePause = useNativePause
        
        
    def st_screen_data_window(self, default=None, key=None): 
        """
        Component to recieve screen stats to help you build a more responsive app.
        - default: default value for component 
        - key: unique identifier for streamlit (will be recognised by streamlit session state)
        """

        component_value = _st_screen_data(windowType="window", setTime=self.setTimeout, key=key, default=default) 
        if self.useNativePause:
            if self.setTimeout != None and isinstance(self.setTimeout, (int, float)): 
                pause = (self.setTimeout/1000) + 1
                time.sleep(pause) 
                return component_value
        return component_value
        
    
    def st_screen_data_window_top(self, default=None, key=None):
        """
        Component to recieve screen stats to help you build a more responsive app.
        - default: default value for component 
        - key: unique identifier for streamlit (will be recognised by streamlit session state)
        """
        component_value = _st_screen_data(windowType="windowTop", setTime=self.setTimeout, key=key, default=default)
        if self.useNativePause:
            if self.setTimeout != None and isinstance(self.setTimeout, (int, float)): 
                pause = (self.setTimeout/1000) + 1
                time.sleep(pause) 
                return component_value 

        return component_value



import streamlit as st
from __init__ import WindowScreenRange
# from st_screen_stats import WindowScreenRange

st.set_page_config(layout="wide")

test_class = WindowScreenRange()
# st.write(test_class.WidthUpperRangeTop(1400))
st.write(test_class.WidthUpperLimit(1300))
# st.write(test_class.WidthLowerLimit(lowerRange=700))
